@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoCutIn.cpp,v 1.6 2009/09/06 15:35:58 bowkenken Exp $
+* $Id: DemoCutIn.cpp,v 1.7 2009/09/13 17:48:33 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -171,6 +171,9 @@ bool DemoCutIn::draw( long frame, long maxFrame, bool flagCutIn )
 {
 	bool flagDone = false;
 
+	if( g_flg_skip_demo_cut_in )
+		return true;
+
 	if( frame < 0 )
 		frame = 0;
 	if( frame > maxFrame ){
