@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoEnding.cpp,v 1.15 2009/07/31 16:32:58 bowkenken Exp $
+* $Id: DemoEnding.cpp,v 1.16 2009/09/12 19:48:08 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -66,6 +66,7 @@ static const long skipFrameSpace = 1;
 DemoEnding::DemoEnding()
 {
 	pStyle = NULL;
+	flagSkipScene = false;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -199,7 +200,7 @@ void DemoEnding::init()
 
 void DemoEnding::initAnime()
 {
-	wait_time = 0;
+	waitTime = 0;
 	frame = 0;
 
 #ifdef D_GTK
@@ -291,7 +292,7 @@ bool DemoEnding::draw()
 		gPcgDun.scrollTile( 0, 0 );
 
 		// ڤؤ
-		wait_time = 0;
+		waitTime = 0;
 		change_scene_gui( SCENE_N_ENDING_EPILOGUE );
 	}
 
@@ -299,8 +300,8 @@ bool DemoEnding::draw()
 
 	if( get_scene() == SCENE_N_ENDING_EPILOGUE ){
 		// 
-		if( wait_time <= 0 ){
-			wait_time = time( NULL ) + ENDING_EPILOGUE_TIME;
+		if( waitTime <= 0 ){
+			waitTime = time( NULL ) + ENDING_EPILOGUE_TIME;
 			frame = 0;
 		}
 
@@ -308,12 +309,14 @@ bool DemoEnding::draw()
 		if( (frame % skipFrameEpilogue) != 0 )
 			return true;
 
-		if( time( NULL ) < wait_time ){
+		if( !flagSkipScene && (time( NULL ) < waitTime) ){
 			// 
 			return drawEpilogue();
 		} else {
+			flagSkipScene = false;
+
 			// ڤؤ
-			wait_time = 0;
+			waitTime = 0;
 			change_scene_gui( SCENE_N_ENDING_SPACE );
 		}
 	}
@@ -322,8 +325,8 @@ bool DemoEnding::draw()
 
 	if( get_scene() == SCENE_N_ENDING_SPACE ){
 		// 
-		if( wait_time <= 0 ){
-			wait_time = time( NULL ) + ENDING_SPACE_TIME;
+		if( waitTime <= 0 ){
+			waitTime = time( NULL ) + ENDING_SPACE_TIME;
 			frame = 0;
 		}
 
@@ -331,12 +334,14 @@ bool DemoEnding::draw()
 		if( (frame % skipFrameSpace) != 0 )
 			return true;
 
-		if( time( NULL ) < wait_time ){
+		if( !flagSkipScene && (time( NULL ) < waitTime) ){
 			// 
 			return drawSpace( false );
 		} else {
+			flagSkipScene = false;
+
 			// ڤؤ
-			wait_time = 0;
+			waitTime = 0;
 			change_scene_gui( SCENE_N_ENDING_STAFF_ROLL );
 		}
 	}
@@ -348,8 +353,16 @@ bool DemoEnding::draw()
 		if( (frame % skipFrameSpace) != 0 )
 			return true;
 
-		// 
-		return drawSpace( true );
+		if( !flagSkipScene ){
+			// 
+			return drawSpace( true );
+		} else {
+			flagSkipScene = false;
+
+			// ڤؤ
+			waitTime = 0;
+			change_scene_gui( SCENE_N_ENDING_END );
+		}
 	}
 
 	// The End
@@ -542,3 +555,12 @@ void DemoEnding::drawChar(
 	mD3.End();
 #endif // D_MFC
 }
+
+////////////////////////////////////////////////////////////////
+// ǥ󥰤Υ򥹥å
+////////////////////////////////////////////////////////////////
+
+void DemoEnding::skipScene()
+{
+	flagSkipScene = true;
+}
