@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoSpace.cpp,v 1.15 2009/07/31 19:03:01 bowkenken Exp $
+* $Id: DemoSpace.cpp,v 1.17 2009/09/12 22:50:56 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -100,6 +100,8 @@ DemoSpace::~DemoSpace()
 
 void DemoSpace::init()
 {
+	g_gui_star_n = GUI_STAR_DFLT_N;
+
 	// طʲθ
 
 	WSCstring dir = STR_DEFAULT_GRAPH_DIR_NAME;
@@ -254,7 +256,7 @@ void DemoSpace::initAnime()
 	// ơ֥
 
 	for( long i = 0; i < COLOR_TAB_MAX_N; i++ ){
-		long col = 64 + (192 * i / COLOR_TAB_MAX_N);
+		long col = 128 + (128 * i / COLOR_TAB_MAX_N);
 		colorTab[i].red = ((col << 8) | col);
 		colorTab[i].green = ((col << 8) | col);
 		colorTab[i].blue = ((col << 8) | col);
@@ -278,7 +280,7 @@ void DemoSpace::initAnime()
 	const UINT txW = 1;
 	const UINT txH = 1;
 	for( long i = 0; i < COLOR_TAB_MAX_N; i++ ){
-		long col = 64 + (192 * i / COLOR_TAB_MAX_N);
+		long col = 128 + (128 * i / COLOR_TAB_MAX_N);
 
 		// ƥ
 
@@ -327,15 +329,15 @@ void DemoSpace::initAnime()
 #endif // D_MFC
 
 	zv = Z_SPEED;
-	for( long i = 0; i < STAR_MAX_N; i++ ){
-		x[i] = randm( XR * 2 ) - XR;
-		y[i] = randm( YR * 2 ) - YR;
-		z[i] = randm( ZR );
+	for( long i = 0; i < GUI_STAR_MAX_N; i++ ){
+		x[i] = randm( XR * 2 + 1 ) - XR;
+		y[i] = randm( YR * 2 + 1 ) - YR;
+		z[i] = randm( ZR - 1 ) + 1;
 	}
 	for( long i = 0; i < NEBULA_MAX_N; i++ ){
-		nx[i] = randm( NXR * 2 ) - NXR;
-		ny[i] = randm( NYR * 2 ) - NYR;
-		nz[i] = randm( NZR );
+		nx[i] = randm( NXR * 2 + 1 ) - NXR;
+		ny[i] = randm( NYR * 2 + 1 ) - NYR;
+		nz[i] = randm( NZR - 1 ) + 1;
 	}
 }
 
@@ -345,7 +347,8 @@ void DemoSpace::initAnime()
 
 void DemoSpace::move()
 {
-	for( long i = 0; i < STAR_MAX_N; i++ ){
+	long nMax = getStarN();
+	for( long i = 0; i < nMax; i++ ){
 		z[i] = ((z[i] - zv) % ZR + ZR) % ZR;
 	}
 	for( long i = 0; i < NEBULA_MAX_N; i++ ){
@@ -415,12 +418,16 @@ bool DemoSpace::draw( bool flagDrawStaffRoll )
 
 	// 
 
-	for( long i = 0; i < STAR_MAX_N; i++ ){
-		long drx = sx + sw / 2;
-		long dry = sy + sh / 2;
-		long zz = z[i] + 1;
-		drx += x[i] / zz;
-		dry += y[i] / zz;
+	long nMax = getStarN();
+	long mx = sx + sw / 2;
+	long my = sy + sh / 2;
+	long zz = 1;
+	long drx = 0;
+	long dry = 0;
+	for( long i = 0; i < nMax; i++ ){
+		zz = z[i] + 1;
+		drx = mx + (x[i] / zz);
+		dry = my + (y[i] / zz);
 
 		drawStar( drx, dry, zz );
 	}
@@ -685,3 +692,18 @@ void DemoSpace::addSpeedZ( long zav )
 {
 	zv += zav;
 }
+
+////////////////////////////////////////////////////////////////
+// ο֤
+// return : ο
+////////////////////////////////////////////////////////////////
+
+long DemoSpace::getStarN()
+{
+	if( g_gui_star_n <= 0 )
+		return GUI_STAR_DFLT_N;
+	if( g_gui_star_n > GUI_STAR_MAX_N )
+		return GUI_STAR_MAX_N;
+
+	return g_gui_star_n;
+}
