@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameJoystick.cpp,v 1.12 2009/06/28 09:37:46 bowkenken Exp $
+* $Id: GameJoystick.cpp,v 1.14 2009/08/21 10:34:03 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -353,137 +353,25 @@ void GameJoystick::joyHat( long n )
 
 void GameJoystick::joyButtonOn( long n )
 {
-	switch( joyKind ){
-	case JOY_KIND_NULL:
-	case JOY_KIND_MAX_N:
-		break;
-	case JOY_KIND_PS:
-		switch( n + 1 ){
-		case 1:
-			gKey.setChar( '+' );
-			break;
-		case 2:
-			gKey.setChar( '\n' );
-			break;
-		case 3:
-			flagContExecB = true;
-			if( flagContExecA && flagContExecB )
-				gKey.setString( ".," );
-			else
-				gKey.setChar( '0' );
-			break;
-		case 4:
-			flagContExecA = true;
-			if( flagContExecA && flagContExecB )
-				gKey.setString( ".," );
-			else
-				gKey.setChar( '.' );
-			break;
-		case 5:
-			gKey.setChar( '/' );
-			break;
-		case 6:
-			gKey.setChar( '*' );
-			break;
-		case 7:
-			gKey.setChar( '-' );
-			break;
-		case 8:
-			gKey.setChar( '+' );
-			break;
-		case 9:
-			gKey.setChar( '\t' );
-			break;
-		case 10:
-			gKey.setChar( 'R' );
-			break;
+	long btn = KEY_N_JOYSTICK_HEAD_N + n;
+	char *macro = get_macro_str( btn );
+
+	if( strcmp( macro, "0" ) == 0 ){
+		flagContExecB = true;
+		if( flagContExecA && flagContExecB ){
+			gKey.setString( ".," );
+			return;
 		}
-		break;
-	case JOY_KIND_SATURN:
-		switch( n + 1 ){
-		case 3:
-			gKey.setChar( '+' );
-			break;
-		case 1:
-			gKey.setChar( '\n' );
-			break;
-		case 2:
-			flagContExecB = true;
-			if( flagContExecA && flagContExecB )
-				gKey.setString( ".," );
-			else
-				gKey.setChar( '0' );
-			break;
-		case 4:
-			flagContExecA = true;
-			if( flagContExecA && flagContExecB )
-				gKey.setString( ".," );
-			else
-				gKey.setChar( '.' );
-			break;
-		case 8:
-			gKey.setChar( '/' );
-			break;
-		case 10:
-			gKey.setChar( '*' );
-			break;
-		case 7:
-			gKey.setChar( '-' );
-			break;
-		case 9:
-			gKey.setChar( '+' );
-			break;
-		case 5:
-			gKey.setChar( '\t' );
-			break;
-		case 6:
-			gKey.setChar( 'R' );
-			break;
-		}
-		break;
-	case JOY_KIND_RAP3:
-		switch( n + 1 ){
-		case 4:
-			gKey.setChar( '+' );
-			break;
-		case 3:
-			gKey.setChar( '\n' );
-			break;
-		case 2:
-			flagContExecB = true;
-			if( flagContExecA && flagContExecB )
-				gKey.setString( ".," );
-			else
-				gKey.setChar( '0' );
-			break;
-		case 1:
-			flagContExecA = true;
-			if( flagContExecA && flagContExecB )
-				gKey.setString( ".," );
-			else
-				gKey.setChar( '.' );
-			break;
-		case 6:
-			gKey.setChar( '/' );
-			break;
-		case 5:
-			gKey.setChar( '*' );
-			break;
-		case 8:
-			gKey.setChar( '-' );
-			break;
-		case 7:
-			gKey.setChar( '+' );
-			break;
-		case 9:
-			gKey.setChar( '\t' );
-			break;
-		case 10:
-			gKey.setChar( 'R' );
-			break;
-		}
-		break;
 	}
+	if( strcmp( macro, "." ) == 0 ){
+		flagContExecA = true;
+		if( flagContExecA && flagContExecB ){
+			gKey.setString( ".," );
+			return;
+		}
+	}
+
+	gKey.setString( macro );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -493,77 +381,16 @@ void GameJoystick::joyButtonOn( long n )
 
 void GameJoystick::joyButtonOff( long n )
 {
-	switch( joyKind ){
-	case JOY_KIND_NULL:
-	case JOY_KIND_MAX_N:
-		break;
-	case JOY_KIND_PS:
-		switch( n + 1 ){
-		case 1:
-		case 2:
-			break;
-		case 3:
-			flagContExecB = false;
-			gKey.setChar( '|' );
-			break;
-		case 4:
-			flagContExecA = false;
-			gKey.setChar( '|' );
-			break;
-		case 5:
-		case 6:
-		case 7:
-		case 8:
-		case 9:
-		case 10:
-			break;
-		}
-		break;
-	case JOY_KIND_SATURN:
-		switch( n + 1 ){
-		case 1:
-			break;
-		case 2:
-			flagContExecB = false;
-			gKey.setChar( '|' );
-			break;
-		case 3:
-			break;
-		case 4:
-			flagContExecA = false;
-			gKey.setChar( '|' );
-			break;
-		case 5:
-		case 6:
-		case 7:
-		case 8:
-		case 9:
-		case 10:
-			break;
-		}
-		break;
-	case JOY_KIND_RAP3:
-		switch( n + 1 ){
-		case 4:
-		case 3:
-			break;
-		case 2:
-			flagContExecB = false;
-			gKey.setChar( '|' );
-			break;
-		case 1:
-			flagContExecA = false;
-			gKey.setChar( '|' );
-			break;
-		case 6:
-		case 5:
-		case 8:
-		case 7:
-		case 9:
-		case 10:
-			break;
-		}
-		break;
+	long btn = KEY_N_JOYSTICK_HEAD_N + n;
+	char *macro = get_macro_str( btn );
+
+	if( strcmp( macro, "0" ) == 0 ){
+		flagContExecB = false;
+		gKey.setChar( '|' );
+	}
+	if( strcmp( macro, "." ) == 0 ){
+		flagContExecA = false;
+		gKey.setChar( '|' );
 	}
 }
 
