@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.cpp,v 1.44 2009/07/12 11:38:28 bowkenken Exp $
+* $Id: GuiMenu.cpp,v 1.46 2009/09/05 11:40:25 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -105,6 +105,8 @@ GuiMenu::GuiMenu()
 {
 	mMenuWin = NULL;
 
+	nSelN = 0;
+
 #ifdef D_GTK
 	vBox = NULL;
 
@@ -397,6 +399,8 @@ void GuiMenu::draw( draw_menu_t *data )
 	if( data == NULL )
 		return;
 
+	nSelN = data->sel_n;
+
 	// ȥ
 
 	WSCstring msgTitle = data->ttl;
@@ -878,12 +882,29 @@ void GuiMenu::setMouseDfltMenu( long sel_n )
 #endif // D_MFC
 }
 
+////////////////////////////////////////////////////////////////
+// ˥塼Υܥ˰ư
+// long nBtn : ˥塼Υܥֹ
+////////////////////////////////////////////////////////////////
+
+void GuiMenu::moveMenuCrsr( long nBtn )
+{
+	long nSel = gGuiMenu.getSelN();
+	if( nBtn < nSel ){
+		for( long i = 0; i < nSel - nBtn; i++ )
+			gKey.setChar( '8' );
+	} else if( nBtn > nSel ){
+		for( long i = 0; i < nBtn - nSel; i++ )
+			gKey.setChar( '2' );
+	}
+}
+
 ////////////////////////////////////////////////////////////////
 // ˥塼Υܥֹ椫饢졼Ѵ
 // long n : ˥塼Υܥֹ
 ////////////////////////////////////////////////////////////////
 
-char	GuiMenu::getAccelKey( long n )
+char GuiMenu::getAccelKey( long n )
 {
 	if( n < 0 )
 		return '\0';
@@ -893,6 +914,16 @@ char	GuiMenu::getAccelKey( long n )
 	return cAccelKey[n];
 }
 
+////////////////////////////////////////////////////////////////
+// Τ˥塼ֹ֤
+// long n : ˥塼ֹ
+////////////////////////////////////////////////////////////////
+
+long GuiMenu::getSelN()
+{
+	return nSelN;
+}
+
 ////////////////////////////////////////////////////////////////
 // ˥塼Υܥ򥯥å (WideStudio)
 // WSCbase *obj : å줿ܥ
@@ -1070,6 +1101,9 @@ gint handle_menu_button_release(
 
 	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
 		gKey.setChar( gGuiMenu.getAccelKey( (long)data ) );
+	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_MIDDLE ){
+		gGuiMenu.moveMenuCrsr( (long)data );
+		gKey.setChar( MENU_COMMAND_KEY_CHAR );
 	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
 		gKey.setChar( '0' );
 	}
