@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.h,v 1.21 2009/07/11 13:57:28 bowkenken Exp $
+* $Id: GuiMenu.h,v 1.23 2009/09/05 11:40:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_MENU_H
@@ -70,6 +70,7 @@ public:
 private:
 
 	char cAccelKey[MENU_MAX_N_PER_PAGE];
+	long nSelN;
 
 #ifdef D_WS
 	WSCvbtn *aBtnMenu[MENU_MAX_N_PER_PAGE];
@@ -119,7 +120,10 @@ public:
 
 	void setMouseDfltMenu( long sel_n );
 
+	void moveMenuCrsr( long nBtn );
+
 	char getAccelKey( long n );
+	long getSelN();
 
 // ץ饤١ȡСؿ
 private:
