@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.cpp,v 1.27 2009/06/03 16:56:09 bowkenken Exp $
+* $Id: GuiNum.cpp,v 1.28 2009/07/03 10:36:42 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -132,6 +132,9 @@ void GuiNum::newWin()
 			"destroy",
 			GTK_SIGNAL_FUNC( handle_num_destroy ),
 			this );
+	gtk_signal_connect( GTK_OBJECT( mNumWin ),
+			"key-press-event",
+			GTK_SIGNAL_FUNC( handleKeyPress ), NULL );
 
 	//
 
