@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.29 2009/06/03 18:09:10 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.30 2009/07/03 10:36:42 bowkenken Exp $
 ***************************************************************/
 
 #define GUI_STAT_CPP
@@ -116,6 +116,9 @@ void GuiStat::newWin()
 	if( mStatWin != NULL )
 		return;
 
+	mStrPreDunLev[0] = '\0';
+	mStrPreTime[0] = '\0';
+
 #ifdef D_GTK
 	// ơɥκ
 
@@ -149,6 +152,9 @@ void GuiStat::newWin()
 			"configure_event",
 			GTK_SIGNAL_FUNC( handle_stat_win_configure ),
 			this );
+	gtk_signal_connect( GTK_OBJECT( mStatWin ),
+			"key-press-event",
+			GTK_SIGNAL_FUNC( handleKeyPress ), NULL );
 
 	// ľܥåκ
 
@@ -516,28 +522,26 @@ void GuiStat::drawMisc()
 	newWin();
 
 	long maxLen = 40;
-	static char sPreDunLev[40 + 1] = "";
-	static char sPreTime[40 + 1] = "";
 	const char *sDunLev = get_stat_dun_lev_str();
 	const char *sTime = get_stat_time_str();
 
 #ifdef D_GTK
-	if( strcmp( sDunLev, sPreDunLev ) != 0 ){
+	if( strcmp( sDunLev, mStrPreDunLev ) != 0 ){
 		gtk_misc_set_alignment( GTK_MISC( labelDunLev ),
 				0.0, 0.5 );
 		gtk_label_set_text( GTK_LABEL( labelDunLev ),
 				(char *)sDunLev );
 
-		str_nz_cpy( sPreDunLev, sDunLev, maxLen );
+		str_nz_cpy( mStrPreDunLev, sDunLev, maxLen );
 	}
 
-	if( strcmp( sTime, sPreTime ) != 0 ){
+	if( strcmp( sTime, mStrPreTime ) != 0 ){
 		gtk_misc_set_alignment( GTK_MISC( labelTime ),
 				0.0, 0.5 );
 		gtk_label_set_text( GTK_LABEL( labelTime ),
 				(char *)sTime );
 
-		str_nz_cpy( sPreTime, sTime, maxLen );
+		str_nz_cpy( mStrPreTime, sTime, maxLen );
 	}
 
 	gtk_widget_show( labelDunLev );
@@ -545,11 +549,11 @@ void GuiStat::drawMisc()
 #endif // D_GTK
 
 #ifdef D_MFC
-	if( strcmp( sDunLev, sPreDunLev ) != 0 ){
+	if( strcmp( sDunLev, mStrPreDunLev ) != 0 ){
 		mStatWin->m_LabelDunLev.SetWindowText( sDunLev );
 	}
 
-	if( strcmp( sTime, sPreTime ) != 0 ){
+	if( strcmp( sTime, mStrPreTime ) != 0 ){
 		mStatWin->m_LabelTime.SetWindowText( sTime );
 	}
 #endif // D_MFC
