@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.h,v 1.13 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: Key.h,v 1.15 2009/07/03 10:36:42 bowkenken Exp $
 ***************************************************************/
 
 #ifndef KEY_H
@@ -71,9 +71,11 @@ public:
 
 	long getChar();
 
-	void setChar( long c, bool flagCheckClear = false );
-	void setString( WSCstring s, bool flagCheckClear = false );
-	void setStringKeyTab( WSCstring s );
+	void setChar( long c, bool flagMacro = false,
+		bool flagCheckClear = false );
+	void setString( WSCstring s, bool flagMacro = false,
+		bool flagCheckClear = false );
+	void setStringKeyTab( WSCstring s, bool flagMacro );
 
 	bool chkBuf();
 
@@ -91,4 +93,12 @@ public:
 #endif // D_MFC
 };
 
+#ifdef D_GTK
+gboolean handleKeyPress(
+	GtkWidget *widget,
+	GdkEventKey *event,
+	gpointer user_data
+);
+#endif // D_GTK
+
 #endif /* KEY_H */
