@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.29 2009/05/29 04:53:09 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.30 2009/08/28 05:40:19 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -575,10 +575,31 @@ PcgTab gPcgTabTrap[] = {
 PcgTab gPcgTabCrsr[] = {
 	{
 		// 
-		MNSTR_KIND_NULL,
+		ATTITUDE_MATE,
 		FACE_MJR_NULL, FACE_MNR_NULL,
 		100,
-		"cursor/",
+		"cursor/main/mate",
+	},
+	{
+		// 
+		ATTITUDE_FRIENDLY,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"cursor/main/friendly",
+	},
+	{
+		// 
+		ATTITUDE_NEUTRAL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"cursor/main/neutral",
+	},
+	{
+		// 
+		ATTITUDE_ENEMY,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"cursor/main/enemy",
 	},
 	{
 		MNSTR_KIND_NULL,
@@ -591,10 +612,31 @@ PcgTab gPcgTabCrsr[] = {
 PcgTab gPcgTabCrsrSub[] = {
 	{
 		// 
-		MNSTR_KIND_NULL,
+		ATTITUDE_MATE,
 		FACE_MJR_NULL, FACE_MNR_NULL,
 		100,
-		"cursor/sub/",
+		"cursor/sub/mate",
+	},
+	{
+		// 
+		ATTITUDE_FRIENDLY,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"cursor/sub/friendly",
+	},
+	{
+		// 
+		ATTITUDE_NEUTRAL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"cursor/sub/neutral",
+	},
+	{
+		// 
+		ATTITUDE_ENEMY,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"cursor/sub/enemy",
 	},
 	{
 		MNSTR_KIND_NULL,
