@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: SelConf.cpp,v 1.15 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: SelConf.cpp,v 1.17 2009/07/31 18:01:17 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -156,10 +156,27 @@ void SelConf::newWin()
 	gtk_box_pack_start( GTK_BOX( vBox ), labelList, FALSE, TRUE, 0 );
 	gtk_widget_show( labelList );
 
+	// 롦ɥ
+
+	scrollWin = gtk_scrolled_window_new( NULL, NULL );
+	if( scrollWin == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_scrolled_window_new()" );
+		return;
+	}
+	gtk_scrolled_window_set_policy(
+			GTK_SCROLLED_WINDOW( scrollWin ),
+			GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
+	gtk_scrolled_window_set_shadow_type(
+			GTK_SCROLLED_WINDOW( scrollWin ),
+			GTK_SHADOW_IN );
+	gtk_box_pack_start( GTK_BOX( vBox ), scrollWin, TRUE, TRUE, 0 );
+	gtk_widget_show( scrollWin );
+
 	// ꥹȡܥåκ
 
 	lsList = gtk_list_new();
-	gtk_box_pack_start( GTK_BOX( vBox ), lsList, TRUE, TRUE, 0 );
+	gtk_scrolled_window_add_with_viewport(
+			GTK_SCROLLED_WINDOW( scrollWin ), lsList );
 	gtk_widget_show( lsList );
 
 	// ꥹȡܥåؤΥ٥ȡϥɥ
@@ -182,11 +199,17 @@ void SelConf::newWin()
 	btnSelConfCancel = gtk_button_new_with_label(
 			MSG_SEL_CONF_CANCEL );
 
+	// ǥեȡܥ
+	GTK_WIDGET_SET_FLAGS( btnSelConfOk, GTK_CAN_DEFAULT );
+
 	gtk_box_pack_end( GTK_BOX( hBox ), btnSelConfOk,
 			FALSE, TRUE, 0 );
 	gtk_box_pack_end( GTK_BOX( hBox ), btnSelConfCancel,
 			FALSE, TRUE, 0 );
 
+	// ǥեȡܥ
+	gtk_widget_grab_default( btnSelConfOk );
+
 	gtk_widget_show( btnSelConfOk );
 	gtk_widget_show( btnSelConfCancel );
 
