@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: WinPos.h,v 1.4 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: WinPos.h,v 1.5 2009/07/11 13:57:28 bowkenken Exp $
 ***************************************************************/
 
 #ifndef WIN_POS_H
@@ -51,13 +51,14 @@ class WinPos {
 
 private:
 	bool flagDraw;
-	long x, y, w, h;
+	long mX, mY, mW, mH;
 
 public:
 	WinPos();
 	~WinPos();
 
 	void *getWin( win_kind_t kind );
+
 	void set(
 		win_kind_t kind,
 		long *px, long *py,
@@ -66,6 +67,9 @@ public:
 		win_kind_t kind,
 		long *px, long *py,
 		long *pw, long *ph );
+
+	void calc( win_kind_t kind );
+
 	void draw( win_kind_t kind, bool flagDlg = false );
 	void wipe( win_kind_t kind, bool flagDlg = false );
 };
