@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.112 2009/09/06 15:35:51 bowkenken Exp $
+* $Id: call.cpp,v 1.114 2009/09/18 23:22:33 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -35,6 +35,10 @@
 extern WSCwindow *StatWin;
 #endif
 
+#ifdef D_GTK
+static GStaticMutex	g_key_buf_mutex = G_STATIC_MUTEX_INIT;
+#endif // D_GTK
+
 static long g_joy_n = 0;
 static joy_kind_t g_joy_kind = JOY_KIND_PS;
 
@@ -80,6 +84,28 @@ void	gui_end( void )
 #endif // D_MFC
 }
 
+/***************************************************************
+* ХåեΥå
+***************************************************************/
+
+void	key_buf_lock( void )
+{
+#ifdef D_GTK
+	g_static_mutex_lock( &g_key_buf_mutex );
+#endif // D_GTK
+}
+
+/***************************************************************
+* ХåեΥå
+***************************************************************/
+
+void	key_buf_unlock( void )
+{
+#ifdef D_GTK
+	g_static_mutex_unlock( &g_key_buf_mutex );
+#endif // D_GTK
+}
+
 /***************************************************************
 * ᥤ󡦥롼פΥåɤڤ
 * void *(*func)( void * ) : 롦Хåؿ
@@ -1400,6 +1426,29 @@ bool_t	call_demo_last_boss_check_done( void )
 	return TRUE;
 }
 
+/***************************************************************
+* ǥ󥰤Υ򥹥å
+***************************************************************/
+
+void	call_demo_ending_skip_scene( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	if( gPcgDun.pDemoEnding == NULL )
+		return;
+
+	gui_begin();
+
+	gPcgDun.pDemoEnding->skipScene();
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ˹礻 BGM κ
 * bool_t flg_gui : GUI ƤФ줿?
