@@ -53,21 +53,42 @@ long	calc_attack_n( chr_t *o_p, const attack_t *attack );
 long	calc_attack_n_fig( chr_t *o_p, const attack_t *attack );
 long	calc_attack_n_mon( chr_t *o_p, const attack_t *attack );
 long	calc_attack_n_hun( chr_t *o_p, const attack_t *attack );
+long	calc_counter_n( chr_t *d_p );
+long	calc_two_sword_fencing_n( chr_t *o_p, const attack_t *attack );
 bool_t	fight_x_1(
+	chr_t *o_p, chr_t *d_p,
+	const attack_t *attack, long range,
+	bool_t flg_counter
+);
+bool_t	fight_two_sword_fencing(
 	chr_t *o_p, chr_t *d_p,
 	const attack_t *attack, long range
 );
+bool_t	fight_counter( chr_t *o_p, chr_t *d_p );
 bool_t	spell_attack(
 	chr_t *o_p, chr_t *d_p,
 	resi_kind_t resi, bool_t flg_stick,
 	abl_kind_t abl, rate_t rate
 );
 void	added_fx( chr_t *chr, resi_kind_t resi );
+void	added_fx_wpn_randm_art(
+	chr_t *o_p, chr_t *d_p,
+	bool_t flg_throw
+);
+void	added_fx_wpn_randm_art_item(
+	chr_t *o_p, chr_t *d_p,
+	item_t *item
+);
 void	fight_fx( chr_t *o_p, chr_t *d_p, const attack_t *attack );
 bool_t	chr_break_door( chr_t *chr, long dr_n );
 bool_t	chr_break_trap( chr_t *chr, trap_t *trap );
 bool_t	chr_break_item( chr_t *chr, item_t *item );
+bool_t	chk_bane( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
+bool_t	chk_killer( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
 bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
+bool_t	chk_guard( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
+bool_t	chk_block( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
+bool_t	chk_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
 bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
 long	get_hit( chr_t *p, const attack_t *attack );
 long	get_dam( chr_t *p, const attack_t *attack );
@@ -92,6 +113,7 @@ rate_t	get_resi_def( chr_t *p, resi_kind_t resi );
 rate_t	get_chr_throw_range_rate( chr_t *o_p, chr_t *d_p );
 rate_t	get_throw_range_rate( long x1, long y1, long x2, long y2 );
 char	*get_msg_attack( const attack_t *attack );
+void	check_memory_fight_c( void );
 
 #ifdef __cplusplus
 }
