@@ -10,6 +10,7 @@ void	inc_turn_all_fx( void );
 void	inc_day_all_fx( void );
 void	natural_cure_hp_chr( chr_t *chr );
 void	natural_cure_mp_chr( chr_t *chr );
+void	natural_cure_exp_chr( chr_t *chr );
 void	modifier_cure_hp_chr( chr_t *chr );
 void	modifier_cure_mp_chr( chr_t *chr );
 void	sober( chr_t *chr );
@@ -48,6 +49,7 @@ bool_t	set_fx_polymorph( fx_t *fx );
 bool_t	clr_fx_polymorph( fx_t *fx );
 bool_t	cancel_fx_vanish( chr_t *chr );
 void	exec_fx_poison( fx_t *fx );
+void	exec_fx_fear( fx_t *fx );
 void	exec_fx_weak( fx_t *fx );
 void	exec_fx_store_light( fx_t *fx );
 modifier_t	*get_modifier_song_mbr( void );
@@ -91,6 +93,7 @@ bool_t	read_scroll_pow_up_armor_def( chr_t *chr );
 bool_t	read_scroll_pow_up_armor_crtcl( chr_t *chr );
 bool_t	read_scroll_pow_up_armor_ac( chr_t *chr );
 bool_t	read_scroll_protect_armor( chr_t *chr );
+bool_t	read_scroll_boomerang( chr_t *chr );
 bool_t	read_scroll_remove_curse( chr_t *chr );
 bool_t	read_scroll_recall( void );
 void	read_scroll_nin( chr_t *chr, scroll_kind_t kind );
@@ -102,13 +105,17 @@ bool_t	fx_darkness( long x, long y );
 bool_t	fx_knock( door_t *door );
 bool_t	fx_lock( door_t *door );
 bool_t	fx_disarm_trap( trap_t *trap, chr_t *chr );
+bool_t	fx_teleport_party_charge( void );
 bool_t	fx_teleport_party( void );
+bool_t	teleport_party_charge( void );
+bool_t	chk_teleport_party( void );
 bool_t	teleport_party( void );
 bool_t	fx_teleport( trgt_kind_t trgt_kind, void *p );
 bool_t	teleport_chr( chr_t *chr );
 bool_t	fx_recall( void );
 bool_t	recall( void );
 bool_t	chk_recall( void );
+void	exec_recall( long n );
 bool_t	fx_shelter( long x, long y );
 bool_t	fx_create_food( chr_t *chr );
 bool_t	fx_identify_all_item( mbr_t *mbr );
@@ -196,6 +203,7 @@ bool_t	fx_pow_up_armor_def( mbr_t *mbr );
 bool_t	fx_pow_up_armor_crtcl( mbr_t *mbr );
 bool_t	fx_pow_up_armor_ac( mbr_t *mbr );
 bool_t	fx_protect_armor( mbr_t *mbr );
+bool_t	fx_boomerang( mbr_t *mbr );
 bool_t	pow_up_wpn_hit( item_t *wpn );
 bool_t	pow_up_wpn_crtcl( item_t *wpn );
 bool_t	pow_up_wpn_dam( item_t *wpn );
@@ -238,6 +246,23 @@ bool_t	fx_wish_cure_hp( chr_t *chr, wish_level_t wish_level );
 bool_t	fx_wish_cure_mp( chr_t *chr, wish_level_t wish_level );
 bool_t	fx_wish_resurrection( chr_t *chr, wish_level_t wish_level );
 bool_t	fx_wish_artifact( chr_t *chr, wish_level_t wish_level );
+bool_t	fx_wpn_randm_art_drain(
+	char mnr,
+	chr_t *o_p, chr_t *d_p,
+	long o_dam, bool_t flg_throw
+);
+bool_t	fx_wpn_randm_art_drain_hp(
+	chr_t *o_p, chr_t *d_p,
+	long o_dam, bool_t flg_throw
+);
+bool_t	fx_wpn_randm_art_drain_mp(
+	chr_t *o_p, chr_t *d_p,
+	long o_dam, bool_t flg_throw
+);
+bool_t	fx_wpn_randm_art_drain_exp(
+	chr_t *o_p, chr_t *d_p,
+	long o_dam, bool_t flg_throw
+);
 bool_t	eat_food( chr_t *chr, item_t *item );
 bool_t	chk_mnstr_catch_food( chr_t *chr, item_t *item );
 bool_t	fx_mnstr_catch_food( chr_t *chr, item_t *item );
@@ -266,6 +291,8 @@ void	inc_chr_caught( chr_t *chr, long n );
 blast_t	*get_blast_spell( spell_kind_t kind );
 blast_t	*get_blast( blast_kind_t kind );
 void	set_blast_size( blast_t *p );
+flg_stat_t	cv_fx_kind_to_flg_stat( fx_kind_t fx_kind );
+resi_kind_t	cv_fx_kind_to_resi_kind( fx_kind_t fx_kind );
 void	lost_fx_chr( chr_t *chr );
 void	lost_fx_chr_sub( chr_t *chr, fx_t *fx );
 fx_t	*asgn_fx( fx_t *p );
@@ -273,6 +300,7 @@ void	free_fx( fx_t *p );
 void	free_fx_all( fx_t *p );
 void	ins_ls_fx( fx_t *ls, fx_t *p );
 fx_t	*srch_fx( fx_t *ls, fx_kind_t kind );
+void	check_memory_fx_c( void );
 
 #ifdef __cplusplus
 }
