@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.138 2009/09/06 12:17:21 bowkenken Exp $
+* $Id: gmain.c,v 1.140 2009/09/12 20:01:39 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -351,6 +351,16 @@ void	ending( void )
 			case CASE_EXIT:
 				exit_game( EXIT_SUCCESS );
 				break;
+			case 'S':
+				set_flg_skip_scene_ending( TRUE );
+				call_demo_ending_skip_scene();
+				break;
+			case CASE_CRSR_UP:
+				add_z_speed_space( +1 );
+				break;
+			case CASE_CRSR_DOWN:
+				add_z_speed_space( -1 );
+				break;
 			}
 		}
 	}
