@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.68 2009/05/31 07:23:45 bowkenken Exp $
+* $Id: gmain.h,v 1.71 2009/09/13 17:48:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -131,6 +131,21 @@ typedef enum {
 	GUI_KEY_KIND_MAX_N,
 } gui_key_kind_t;
 
+/* ꡼å */
+
+#define	CHECK_MEMORY_MAX_LEN	32
+#define	CHECK_MEMORY_INIT	{ \
+	0xbe, 0xef, 0xbe, 0xef, 0xbe, 0xef, 0xbe, 0xef, \
+	0xbe, 0xef, 0xbe, 0xef, 0xbe, 0xef, 0xbe, 0xef, \
+	0xbe, 0xef, 0xbe, 0xef, 0xbe, 0xef, 0xbe, 0xef, \
+	0xbe, 0xef, 0xbe, 0xef, 0xbe, 0xef, 0xbe, 0xef, \
+}
+
+typedef unsigned char	check_memory_t[CHECK_MEMORY_MAX_LEN];
+
+#define	check_memory_def( var )	\
+	static check_memory_t	var = CHECK_MEMORY_INIT;
+
 /***************************************************************
 * ѿ
 ***************************************************************/
@@ -210,9 +225,21 @@ EXTERN long	g_randm_seed_save;
 /* ƥμϤλ񤹤 */
 EXTERN bool_t	g_flg_send_item_exec_turn;
 
+/* åȡΥǥ򥹥åפ뤫? */
+EXTERN bool_t	g_flg_skip_demo_cut_in;
+
+/* ο CUI */
+EXTERN long	g_cui_star_n;
+
+/* ο GUI */
+EXTERN long	g_gui_star_n;
+
 /* ǥХå⡼ */
 EXTERN bool_t	g_flg_debug;
 
+/* ꡼å */
+EXTERN bool_t	g_flg_check_memory;
+
 #ifdef __cplusplus
 }
 #endif
