@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,18 +25,21 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.91 2008/02/14 08:44:16 bowkenken Exp $
+* $Id: item.h,v 1.103 2009/09/17 22:29:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
 #define	ITEM_H
 
-/* ƥ */
+/***************************************************************
+* ƥ
+***************************************************************/
 
 #include	"spell.h"
 #include	"trap.h"
 
 #include	"item-kind.h"
+#include	"item-randm-art.h"
 
 /**/
 
@@ -49,13 +52,20 @@
 
 /* ƥ̾κʸ */
 #define	ITEM_NAME_MAX_LEN	60
+#define	ITEM_NAME_MAX_BYTE	\
+	(ITEM_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
+
 /* ʤΥƥ̾κʸ */
 #define	ITEM_ART_NAME_MAX_LEN	(ITEM_NAME_MAX_LEN + 16)
+#define	ITEM_ART_NAME_MAX_BYTE	\
+	(ITEM_ART_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /* ʪΥȥκ粻 */
 #define	SCROLL_TTL_SYLLABLE_MAX_N	4
 /* ʪΥȥκʸ */
 #define	SCROLL_TTL_MAX_LEN	50
+#define	SCROLL_TTL_MAX_BYTE	\
+	(SCROLL_TTL_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /* ţʿܿ */
 #define	SPIKE_AVE_N	11
@@ -136,9 +146,9 @@
 
 #define	FACE_MJR_INST	FACE_MJR_MISC
 #define	FACE_MNR_INST	'i'
-#define	FACE_MNR_INST_BRASS	'B'
-#define	FACE_MNR_INST_WOODWIND	'W'
 #define	FACE_MNR_INST_STRINGED	'S'
+#define	FACE_MNR_INST_WOODWIND	'W'
+#define	FACE_MNR_INST_BRASS	'B'
 #define	FACE_MNR_INST_PERCUSSION	'P'
 #define	FACE_MNR_INST_MISC	'M'
 
@@ -221,6 +231,7 @@
 #define	POTION_PRICE_D	400
 #define	POTION_PRICE_E	200
 
+#define	SCROLL_PRICE_S	10000
 #define	SCROLL_PRICE_A	1000
 #define	SCROLL_PRICE_B	800
 #define	SCROLL_PRICE_C	600
@@ -292,6 +303,7 @@ typedef enum {
 	WPN_KIND_CUTLASS,
 	WPN_KIND_SHOTEL,
 	WPN_KIND_KATANA,
+	WPN_KIND_WAKIZASHI,
 /* 쥤ԥ */
 	WPN_KIND_RAPIER,
 	WPN_KIND_ESTOC,
@@ -534,6 +546,7 @@ typedef enum {
 	SCROLL_KIND_POW_UP_ARMOR_CRTCL,
 	SCROLL_KIND_POW_UP_ARMOR_AC,
 	SCROLL_KIND_PROTECT_ARMOR,
+	SCROLL_KIND_BOOMERANG,
 	SCROLL_KIND_REMOVE_CURSE,
 	SCROLL_KIND_RECALL,
 	SCROLL_KIND_TYPHOON,
@@ -644,21 +657,8 @@ typedef enum {
 
 typedef enum {
 	INST_KIND_NULL,
-	INST_KIND_TRUMPET,
-	INST_KIND_TROMBONE,
-	INST_KIND_FLUGELHORN,
-	INST_KIND_CORNET,
-	INST_KIND_HORN,
-	INST_KIND_TUBA,
-	INST_KIND_SOUSAPHONE,
-	INST_KIND_BUGLE,
-	INST_KIND_FLUTE,
-	INST_KIND_CLARINET,
-	INST_KIND_BASS_CLARINET,
-	INST_KIND_PICCOLO,
-	INST_KIND_OBOE,
-	INST_KIND_BASSOON,
-	INST_KIND_SAXOPHONE,
+
+	/* STRINGED -  */
 	INST_KIND_VIOLIN,
 	INST_KIND_VIOLA,
 	INST_KIND_CELLO,
@@ -667,6 +667,27 @@ typedef enum {
 	INST_KIND_MANDOLIN,
 	INST_KIND_BANJO,
 	INST_KIND_SITAR,
+
+	/* WOODWIND - ǽͶ */
+	INST_KIND_FLUTE,
+	INST_KIND_CLARINET,
+	INST_KIND_BASS_CLARINET,
+	INST_KIND_PICCOLO,
+	INST_KIND_OBOE,
+	INST_KIND_BASSOON,
+	INST_KIND_SAXOPHONE,
+
+	/* BRASS - ǽͼ */
+	INST_KIND_TRUMPET,
+	INST_KIND_TROMBONE,
+	INST_KIND_FLUGELHORN,
+	INST_KIND_CORNET,
+	INST_KIND_HORN,
+	INST_KIND_TUBA,
+	INST_KIND_SOUSAPHONE,
+	INST_KIND_BUGLE,
+
+	/* PERCUSSION -  */
 	INST_KIND_BASS_DRUM,
 	INST_KIND_TENOR_DRUM,
 	INST_KIND_SNARE_DRUM,
@@ -680,10 +701,13 @@ typedef enum {
 	INST_KIND_CASTANETS,
 	INST_KIND_TUBULAR_BELLS,
 	INST_KIND_XYLOPHONE,
+
+	/* MISC -  */
 	INST_KIND_ACCORDION,
 	INST_KIND_BAGPIPE,
 	INST_KIND_HARMONICA,
 	INST_KIND_KAZOO,
+
 	INST_KIND_MAX_N,
 } inst_kind_t;
 
@@ -735,6 +759,7 @@ typedef enum {
 	FOOD_KIND_STEWED_BEEF,
 	FOOD_KIND_CONSOMME,
 	FOOD_KIND_POTAGE,
+	FOOD_KIND_SOUP_OF_TURNIP,
 	FOOD_KIND_APPLE_PIE,
 	FOOD_KIND_APPLE,
 	FOOD_KIND_GRAPE,
@@ -932,7 +957,8 @@ typedef struct {
 	long	add_hit;	/* Ͻ */
 	long	add_crtcl;	/* ƥ뽤 */
 	long	add_dam;	/* ᡼ */
-	char	slayer;	/*  */
+	char	slayer;	/* ᡼ܲ (ߴݻΤθŤ) */
+	wpn_randm_art_t	randm_art[WPN_RANDM_ART_LS_MAX_N + 1];
 	flg_wpn_tab_t	flg;	/* ե饰 */
 } wpn_t;
 
@@ -941,6 +967,7 @@ typedef struct {
 	long	add_def;	/* ɸϽ */
 	long	add_crtcl;	/* ƥ뽤 */
 	long	add_ac;	/* ޡ饹 */
+	armor_randm_art_t	randm_art[ARMOR_RANDM_ART_LS_MAX_N + 1];
 } armor_t;
 
 typedef struct {
@@ -977,6 +1004,9 @@ typedef struct {
 typedef struct {
 	light_kind_t	kind;
 	long	turn;
+	wish_level_t	wish_level;
+	long	wish_n;
+	bool_t	flg_used;
 } light_t;
 
 typedef struct {
@@ -1158,7 +1188,7 @@ typedef struct {
 	n_msg_idx_t	ttl_idx[SCROLL_TTL_SYLLABLE_MAX_N + 1];
 
 	/* ȥ */
-	char	ttl[SCROLL_TTL_MAX_LEN + 1];
+	char	ttl[SCROLL_TTL_MAX_BYTE + 1];
 
 	/* ̺ѥե饰 */
 	bool_t	flg_identified;
@@ -1266,6 +1296,9 @@ typedef struct {
 	/* ̾ */
 	char	*name;
 	n_msg_t	name_n;
+	/* ̸̾ */
+	char	*i_name;
+	n_msg_t	i_name_n;
 
 	/*  */
 	light_kind_t	kind;
@@ -1283,6 +1316,11 @@ typedef struct {
 	long	max_turn;
 	/* ǽե饰 */
 	bool_t	flg_fill;
+
+	/* ˡΥפμ */
+	wish_level_t	wish_level;
+	/* ˡΥפκѲ */
+	long	wish_max_n;
 } light_tab_t;
 
 typedef struct {
@@ -1428,6 +1466,7 @@ typedef struct {
 	inst_kind_t	inst;
 	anthology_kind_t	anthology;
 	light_kind_t	light;
+	wish_level_t	wish_level;
 	food_kind_t	food;
 	item_kind_dat_tobacco_t	tobacco;
 	pipe_kind_t	pipe;
@@ -1448,9 +1487,11 @@ typedef struct item_t {
 	bool_t	flg_garbage;
 
 	/* ̾ */
-	char	name[ITEM_NAME_MAX_LEN + 1];
+	char	name[ITEM_NAME_MAX_BYTE + 1];
 	/* ̾ */
-	char	art_name[ITEM_ART_NAME_MAX_LEN + 1];
+	char	art_name[ITEM_ART_NAME_MAX_BYTE + 1];
+	/* ̾ */
+	char	alias[ITEM_NAME_MAX_BYTE + 1];
 
 	/*  */
 	item_kind_t	kind;
