@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.77 2009/08/09 07:37:02 bowkenken Exp $
+* $Id: last-boss.c,v 1.84 2009/09/19 13:44:09 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -35,6 +35,12 @@
 #define	LAST_BOSS_C
 #include	"inc.h"
 
+/***************************************************************
+* 
+***************************************************************/
+
+#define	FRAME_SKIP_MAX	4
+
 /***************************************************************
 * ѿ
 ***************************************************************/
@@ -69,6 +75,7 @@ static pos_t	xx_pos;
 static pos_t	g_core;
 static last_boss_ptn_t	last_boss_ptn_bg;
 static last_boss_ptn_t	last_boss_ptn_fg;
+static long	g_frame_skip;
 
 check_memory_def( check_memory_last_boss_c_xx_pos )
 
@@ -389,6 +396,9 @@ check_memory_def( check_memory_last_boss_c_xx_attack_slap )
 
 void	init_last_boss( void )
 {
+	g_frame_skip = 1;
+	g_flg_skip_demo_cut_in = FALSE;
+
 	flg_open_xx_jaw = FALSE;
 	flg_slap_xx_arm_left = FALSE;
 	flg_slap_xx_arm_right = FALSE;
@@ -809,6 +819,7 @@ void	draw_last_boss( void )
 		draw_words_xex( MSG_WORDS_LAST_BOSS_ENCOUNTER_XEX_10 );
 		draw_words_exel( MSG_WORDS_LAST_BOSS_ENCOUNTER_EXEL_1 );
 		draw_words_exeler( MSG_WORDS_LAST_BOSS_ENCOUNTER_EXELER_1 );
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_ENCOUNTER_CUT_OUT:
 		break;
@@ -874,6 +885,7 @@ void	draw_last_boss( void )
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		draw_words_exeler( MSG_WORDS_LAST_BOSS_EXELER_1 );
 		draw_words_exeler( MSG_WORDS_LAST_BOSS_EXELER_2 );
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_EXELER_CUT_OUT:
 		break;
@@ -883,7 +895,6 @@ void	draw_last_boss( void )
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_EXELER_ENTER:
-		set_vfx_wait( _100_PERCENT );
 		draw_exeler_enter();
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
@@ -923,6 +934,7 @@ void	draw_last_boss( void )
 		draw_words_xex( MSG_WORDS_LAST_BOSS_XEX_1 );
 		draw_words_xex( MSG_WORDS_LAST_BOSS_XEX_2 );
 		draw_words_xex( MSG_WORDS_LAST_BOSS_XEX_3 );
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_XEX_CUT_OUT:
 		break;
@@ -932,7 +944,6 @@ void	draw_last_boss( void )
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_XX_ENTER:
-		set_vfx_wait( _100_PERCENT );
 		draw_xx_enter();
 		break;
 	case LAST_SCENE_N_XX_WORDS:
@@ -941,6 +952,7 @@ void	draw_last_boss( void )
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		draw_words_xx( MSG_WORDS_LAST_BOSS_XX_1 );
 		draw_words_xx( MSG_WORDS_LAST_BOSS_XX_2 );
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
@@ -1063,7 +1075,7 @@ void	draw_exel_enter( void )
 		draw_mnstr( p2 );
 		draw_mnstr( p3 );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXEL_ENTER_WAIT_FRAME_N );
+		wait_clock( EXEL_ENTER_WAIT_FRAME_N );
 	}
 
 	for( dy = EXEL_JUMP_MAX_Y; dy >= 0; dy-- ){
@@ -1078,7 +1090,7 @@ void	draw_exel_enter( void )
 		draw_mnstr( p2 );
 		draw_mnstr( p3 );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXEL_ENTER_WAIT_FRAME_N );
+		wait_clock( EXEL_ENTER_WAIT_FRAME_N );
 	}
 }
 
@@ -1112,7 +1124,7 @@ void	draw_exel_hyper( void )
 
 		draw_mnstr( p );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXEL_HYPER_NORMAL_WAIT_FRAME_N );
+		wait_clock( EXEL_HYPER_NORMAL_WAIT_FRAME_N );
 
 		/* 緿 */
 
@@ -1129,7 +1141,7 @@ void	draw_exel_hyper( void )
 
 		draw_mnstr( p );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXEL_HYPER_PERFECT_WAIT_FRAME_N );
+		wait_clock( EXEL_HYPER_PERFECT_WAIT_FRAME_N );
 	}
 }
 
@@ -1198,7 +1210,7 @@ void	draw_exeler_enter( void )
 		draw_mnstr( p2 );
 		draw_mnstr( p3 );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXELER_ENTER_WAIT_FRAME_N );
+		wait_clock( EXELER_ENTER_WAIT_FRAME_N );
 	}
 }
 
@@ -1232,7 +1244,7 @@ void	draw_exeler_hyper( void )
 
 		draw_mnstr( p );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXELER_HYPER_NORMAL_WAIT_FRAME_N );
+		wait_clock( EXELER_HYPER_NORMAL_WAIT_FRAME_N );
 
 		/* 緿 */
 
@@ -1249,7 +1261,7 @@ void	draw_exeler_hyper( void )
 
 		draw_mnstr( p );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXELER_HYPER_PERFECT_WAIT_FRAME_N );
+		wait_clock( EXELER_HYPER_PERFECT_WAIT_FRAME_N );
 	}
 }
 
@@ -2523,7 +2535,7 @@ pos_t	get_xx_pos( void )
 void	wait_frame_gui( long frame )
 {
 	if( g_flg_gui )
-		wait_frame( frame );
+		wait_100_n_msec( 5 );
 }
 
 /***************************************************************
@@ -2545,6 +2557,15 @@ void	act_mnstr_xx( mnstr_t *p )
 	pty = get_party();
 	kind = (xx_act_kind_t)(randm( XX_ACT_KIND_MAX_N - 1 ) + 1);
 
+	g_frame_skip = FRAME_SKIP_MAX
+			* (_100_PERCENT - get_vfx_wait())
+			/ _100_PERCENT
+			+ 1;
+	if( g_frame_skip < 1 )
+		g_frame_skip = 1;
+	if( g_frame_skip > FRAME_SKIP_MAX )
+		g_frame_skip = FRAME_SKIP_MAX;
+
 #if	0
 	if( g_flg_debug )
 		kind = XX_ACT_KIND_SLAP;
@@ -2729,7 +2750,8 @@ void	xx_act_heat_draw( mnstr_t *p )
 			break;
 
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		if( (xx_heat.head_y % XX_HEAT_DY) == 0 ){
 			n = (xx_heat.head_y / XX_HEAT_DY) % XX_HEAT_MAX_N;
@@ -2748,20 +2770,24 @@ void	xx_act_heat_draw( mnstr_t *p )
 			if( m >= blast_max_n )
 				continue;
 
-			draw_blast_cui( CHR_KIND_MBR,
-					xx_heat.blast_x[n],
-					xx_heat.blast_y[n],
-					&(xx_blast_heat[m]),
-					"XX" );
+			if( (i % g_frame_skip) == 0 ){
+				draw_blast_cui( CHR_KIND_MBR,
+						xx_heat.blast_x[n],
+						xx_heat.blast_y[n],
+						&(xx_blast_heat[m]),
+						"XX" );
+			}
 
 			xx_heat.blast_n[n]++;
 		}
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_HEAT, &xx_heat );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_HEAT, &xx_heat );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_HEAT_WAIT_FRAME_N );
+			wait_clock( XX_HEAT_WAIT_FRAME_N );
+		}
 
 		xx_heat.head_y++;
 	}
@@ -2846,15 +2872,18 @@ void	xx_act_cold_draw( mnstr_t *p )
 
 		flg_next = TRUE;
 		for( n = 0; n < MBR_MAX_N; n++ ){
+			long	d;
+
 			if( !clip_pos( xx_cold.bit_mx[n],
 					xx_cold.bit_my[n] ) ){
 				continue;
 			}
 
-			xx_cold.bit_x[n] += sgn_l( xx_cold.bit_mx[n]
-					- xx_cold.bit_x[n] );
-			xx_cold.bit_y[n] += sgn_l( xx_cold.bit_my[n]
-					- xx_cold.bit_y[n] );
+			d = sgn_l( xx_cold.bit_mx[n] - xx_cold.bit_x[n] );
+			xx_cold.bit_x[n] += d;
+
+			d = sgn_l( xx_cold.bit_my[n] - xx_cold.bit_y[n] );
+			xx_cold.bit_y[n] += d;
 
 			if( xx_cold.bit_x[n] != xx_cold.bit_mx[n] )
 				flg_next = FALSE;
@@ -2868,23 +2897,26 @@ void	xx_act_cold_draw( mnstr_t *p )
 					NULL );
 		}
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_COLD, &xx_cold );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_COLD, &xx_cold );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_COLD_BIT_WAIT_FRAME_N );
+			wait_clock( XX_COLD_BIT_WAIT_FRAME_N );
+		}
 
 		if( flg_next )
 			break;
 	}
 
-	wait_frame( XX_COLD_NEXT_WAIT_FRAME_N );
+	wait_clock( XX_COLD_NEXT_WAIT_FRAME_N );
 
 	/* 졼ȯͤ */
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		for( n = 0; n < MBR_MAX_N; n++ ){
 			if( !clip_pos( xx_cold.bit_mx[n],
@@ -2915,25 +2947,29 @@ void	xx_act_cold_draw( mnstr_t *p )
 			}
 			curs_attrset_dflt();
 
-			draw_blast_cui( CHR_KIND_NULL,
-					xx_cold.bit_x[n],
-					xx_cold.bit_y[n],
-					&(xx_bit[n]),
-					NULL );
+			if( (i % g_frame_skip) == 0 ){
+				draw_blast_cui( CHR_KIND_NULL,
+						xx_cold.bit_x[n],
+						xx_cold.bit_y[n],
+						&(xx_bit[n]),
+						NULL );
+			}
 		}
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_COLD, &xx_cold );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_COLD, &xx_cold );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_COLD_LASER_WAIT_FRAME_N );
+			wait_clock( XX_COLD_LASER_WAIT_FRAME_N );
+		}
 
 		xx_cold.laser_len += XX_COLD_LASER_ADD_LEN;
 		if( xx_cold.laser_len > XX_COLD_LASER_MAX_LEN )
 			break;
 	}
 
-	wait_frame( XX_COLD_END_WAIT_FRAME_N );
+	wait_clock( XX_COLD_END_WAIT_FRAME_N );
 }
 
 /***************************************************************
@@ -2995,7 +3031,8 @@ void	xx_act_mind_draw( mnstr_t *p )
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		/* ư */
 
@@ -3008,13 +3045,16 @@ void	xx_act_mind_draw( mnstr_t *p )
 		}
 
 		xx_mind_move( &xx_mind );
-		xx_mind_draw( &xx_mind );
+		if( (i % g_frame_skip) == 0 )
+			xx_mind_draw( &xx_mind );
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_MIND, &xx_mind );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_MIND, &xx_mind );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_MIND_WAIT_FRAME_N );
+			wait_clock( XX_MIND_WAIT_FRAME_N );
+		}
 
 		xx_mind.rate += XX_MIND_ADD_RATE;
 		xx_mind.refract_idx++;
@@ -3210,19 +3250,23 @@ void	xx_act_acid_draw( mnstr_t *p )
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		if( xx_acid_chk_end( &xx_acid ) )
 			break;
 
 		xx_acid_move( &xx_acid );
-		xx_acid_draw( &xx_acid );
+		if( (i % g_frame_skip) == 0 )
+			xx_acid_draw( &xx_acid );
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_ACID, &xx_acid );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_ACID, &xx_acid );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_ACID_WAIT_FRAME_N );
+			wait_clock( XX_ACID_WAIT_FRAME_N );
+		}
 
 		xx_acid.homing_idx++;
 		xx_acid.homing_idx %= XX_ACID_IMAGE_MAX_N;
@@ -3480,7 +3524,8 @@ void	xx_act_rotation_draw( mnstr_t *p )
 		}
 
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_COLD );
 		for( r = 0; r < XX_ROTATION_RING_MAX_N; r++ ){
@@ -3508,11 +3553,14 @@ void	xx_act_rotation_draw( mnstr_t *p )
 		}
 		curs_attrset_dflt();
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_PARALYZE, &xx_rotation );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_PARALYZE,
+					&xx_rotation );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_ROTATION_WAIT_FRAME_N );
+			wait_clock( XX_ROTATION_WAIT_FRAME_N );
+		}
 
 		sg = +1;
 		for( r = 0; r < XX_ROTATION_RING_MAX_N; r++ ){
@@ -3646,7 +3694,8 @@ void	xx_act_whirl_draw( mnstr_t *p )
 		}
 
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_HEAT );
 		for( n = 0; n < XX_WHIRL_MAX_N; n++ ){
@@ -3669,11 +3718,13 @@ void	xx_act_whirl_draw( mnstr_t *p )
 		}
 		curs_attrset_dflt();
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_POISON, &xx_whirl );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_POISON, &xx_whirl );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_WHIRL_WAIT_FRAME_N );
+			wait_clock( XX_WHIRL_WAIT_FRAME_N );
+		}
 
 		/* ȯ */
 
@@ -3786,7 +3837,8 @@ void	xx_act_fan_draw( mnstr_t *p )
 		}
 
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_MIND );
 		for( n = 0; n < XX_FAN_MAX_N; n++ ){
@@ -3814,11 +3866,13 @@ void	xx_act_fan_draw( mnstr_t *p )
 		}
 		curs_attrset_dflt();
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_SLEEP, &xx_fan );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_SLEEP, &xx_fan );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_FAN_WAIT_FRAME_N );
+			wait_clock( XX_FAN_WAIT_FRAME_N );
+		}
 
 		/* ư */
 
@@ -3899,14 +3953,14 @@ void	xx_act_slap( mnstr_t *p )
 void	xx_act_slap_draw( mnstr_t *p )
 {
 	set_slap_xx_arm_left( TRUE );
-	wait_frame( XX_SLAP_WAIT_FRAME_N );
+	wait_clock( XX_SLAP_WAIT_FRAME_N );
 	set_slap_xx_arm_left( FALSE );
 
 	set_slap_xx_arm_right( TRUE );
-	wait_frame( XX_SLAP_WAIT_FRAME_N );
+	wait_clock( XX_SLAP_WAIT_FRAME_N );
 	set_slap_xx_arm_right( FALSE );
 
-	wait_frame( XX_SLAP_WAIT_FRAME_N );
+	wait_clock( XX_SLAP_WAIT_FRAME_N );
 }
 
 /***************************************************************
