@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.73 2009/07/23 12:25:21 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.75 2009/09/19 02:13:03 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -752,11 +752,21 @@ void	handle_map_scroll_changed(
 
 gint	handle_map_draw( gpointer p )
 {
+	static long	flagDrawing = false;
+
+	if( flagDrawing )
+		return TRUE;
+	flagDrawing = true;
+	gui_begin();
+
 	gJoystick.checkEvent();
 
 	if( get_scene() == SCENE_N_LAST_BOSS ){
-		if( !gPcgDun.drawLastBoss() )
+		if( !gPcgDun.drawLastBoss() ){
+			gui_end();
+			flagDrawing = false;
 			return TRUE;
+		}
 	} else if( chk_scene_group( SCENE_GROUP_N_TITLE ) ){
 		gPcgDun.drawTitle();
 	} else if( chk_scene_group( SCENE_GROUP_N_ENDING ) ){
@@ -769,6 +779,8 @@ gint	handle_map_draw( gpointer p )
 			gSelMbrGraph->redraw();
 #endif
 	} else {
+		gui_end();
+		flagDrawing = false;
 		return TRUE;
 	}
 
@@ -780,6 +792,8 @@ gint	handle_map_draw( gpointer p )
 	rect.height = drawingArea->allocation.height;
 	gtk_widget_draw( GTK_WIDGET( drawingArea ), &rect );
 
+	gui_end();
+	flagDrawing = false;
 	return TRUE;
 }
 
