@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-tab.h,v 1.10 2008/09/09 12:32:55 bowkenken Exp $
+* $Id: mnstr-tab.h,v 1.15 2009/02/22 10:36:45 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_TAB_H
@@ -74,10 +74,6 @@ mnstr_tab_t	mnstr_tab[] = {
 #include	"mnstr-gen-tab.h"
 };
 
-/***************************************************************
-* ܥΥꥹ
-***************************************************************/
-
 #if	0
 typedef struct {
 	/* 󥹥μ */
@@ -92,19 +88,48 @@ typedef struct {
 } mnstr_lev_tab_t;
 #endif
 
+/***************************************************************
+* ܥΥꥹ
+***************************************************************/
+
 mnstr_lev_tab_t	mnstr_boss_lev_tab[] = {
 	{ MNSTR_KIND_HIGH_RE_HOO,	/*  */
 		+0, +1, 10, 10, },
 	{ MNSTR_KIND_GREAT_MINOTAUR,	/* Ⱦ */
 		+0, +1, 20, 20, },
-	{ MNSTR_KIND_BLACK_UNICORN,	/*  */
+	{ MNSTR_KIND_BILLION_ELEMENTAL,	/*  */
 		+0, +1, 30, 30, },
-	{ MNSTR_KIND_MEDUSA_ZOMBIE,	/* Ⱦ */
+	{ MNSTR_KIND_CYBERN,	/* ˡʪ */
 		+0, +1, 40, 40, },
 	{ MNSTR_KIND_GIGANTIC_CENTIPEDE,	/* ʪ */
 		+0, +1, 50, 50, },
-	{ MNSTR_KIND_VAMPIRE_LORD,	/* ǥå */
+	{ MNSTR_KIND_MEDUSA_ZOMBIE,	/* Ⱦ */
 		+0, +1, 60, 60, },
+	{ MNSTR_KIND_BLACK_UNICORN,	/*  */
+		+0, +1, 70, 70, },
+	{ MNSTR_KIND_VAMPIRE_LORD,	/* ǥå */
+		+0, +1, 80, 80, },
+	{ MNSTR_KIND_RELATIVISTIC_DAEMON,	/*  */
+		+0, +1, 90, 90, },
+	{ MNSTR_KIND_ETERNAL_DRAGON,	/* --󥷥ȡɥ饴 */
+		+0, +1, 100, 100, },
+	{ MNSTR_KIND_NULL,
+		+0, +0, 0, 0, },
+};
+
+/***************************************************************
+* 饹ܥΥꥹ
+***************************************************************/
+
+mnstr_lev_tab_t	mnstr_last_boss_lev_tab[] = {
+	{ MNSTR_KIND_EXEL,
+		+0, +1, 99999, 99999, },
+	{ MNSTR_KIND_EXELER,
+		+0, +1, 99999, 99999, },
+	{ MNSTR_KIND_XEX,
+		+0, +1, 99999, 99999, },
+	{ MNSTR_KIND_XX,
+		+0, +1, 99999, 99999, },
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
@@ -195,7 +220,7 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_2[] = {
 		+0, +0, 14, 16, },
 	{ MNSTR_KIND_OGRE,	/*  */
 		+0, +0, 15, 17, },
-	{ MNSTR_KIND_GIANT_ANT,	/*  */
+	{ MNSTR_KIND_GIANT_SPIDER,	/*  */
 		+0, +0, 16, 18, },
 	{ MNSTR_KIND_GNOLL,	/*  */
 		+0, +0, 17, 19, },
@@ -211,30 +236,30 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_2[] = {
 /* BOSS MNSTR_KIND_GREAT_MINOTAUR, */	/* Ⱦ */
 
 mnstr_lev_tab_t	mnstr_lev_tab_stage_3[] = {
-	{ MNSTR_KIND_GIANT_SPIDER,	/*  */
+	{ MNSTR_KIND_IMP,	/*  */
 		+0, +0, 21, 23, },
 	{ MNSTR_KIND_RUST_MONSTER,	/*  */
 		+0, +0, 22, 24, },
-	{ MNSTR_KIND_IMP,	/*  */
-		+0, +0, 23, 25, },
 	{ MNSTR_KIND_GHOUL,	/* ǥå */
-		+0, +0, 24, 26, },
+		+0, +0, 23, 25, },
 	{ MNSTR_KIND_TROLL,	/*  */
-		+0, +0, 25, 27, },
+		+0, +0, 24, 26, },
 	{ MNSTR_KIND_SLIME,	/* ʪ */
-		+0, +0, 26, 28, },
+		+0, +0, 25, 27, },
 	{ MNSTR_KIND_HIPPOGRIFF,	/*  */
-		+0, +0, 27, 29, },
+		+0, +0, 26, 28, },
 	{ MNSTR_KIND_JACK_O_LANTERN,	/*  */
-		+0, +0, 28, 30, },
+		+0, +0, 27, 29, },
 	{ MNSTR_KIND_INVISIBLE_STALKER,	/* ˡʪ */
+		+0, +0, 28, 30, },
+	{ MNSTR_KIND_GIANT_ANT,	/*  */
 		+0, +0, 29, 31, },
 	{ MNSTR_KIND_GRIFFON,	/*  */
 		+0, +0, 30, 32, },
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
-/* BOSS MNSTR_KIND_BLACK_UNICORN, */	/*  */
+/* BOSS MNSTR_KIND_BILLION_ELEMENTAL, */	/*  */
 
 mnstr_lev_tab_t	mnstr_lev_tab_stage_4[] = {
 	{ MNSTR_KIND_GHOST,	/* ǥå */
@@ -260,7 +285,7 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_4[] = {
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
-/* BOSS MNSTR_KIND_MEDUSA_ZOMBIE, */	/* Ⱦ */
+/* BOSS MNSTR_KIND_CYBERN, */	/* ˡʪ */
 
 mnstr_lev_tab_t	mnstr_lev_tab_stage_5[] = {
 	{ MNSTR_KIND_WOOD_GOLEM,	/* ˡʪ */
@@ -312,7 +337,7 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_6[] = {
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
-/* BOSS MNSTR_KIND_VAMPIRE_LORD, */	/* ǥå */
+/* BOSS MNSTR_KIND_MEDUSA_ZOMBIE, */	/* Ⱦ */
 
 mnstr_lev_tab_t	mnstr_lev_tab_stage_7[] = {
 	{ MNSTR_KIND_SALAMANDER,	/*  */
@@ -338,6 +363,7 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_7[] = {
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
+/* BOSS MNSTR_KIND_BLACK_UNICORN, */	/*  */
 
 mnstr_lev_tab_t	mnstr_lev_tab_stage_8[] = {
 	{ MNSTR_KIND_M_RED_DRAGON,	/* --ޥʡɥ饴 */
@@ -363,6 +389,7 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_8[] = {
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
+/* BOSS MNSTR_KIND_VAMPIRE_LORD, */	/* ǥå */
 
 mnstr_lev_tab_t	mnstr_lev_tab_stage_9[] = {
 	{ MNSTR_KIND_MIMIC,	/* ˡʪ */
@@ -383,11 +410,12 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_9[] = {
 		+0, +0, 88, 90, },
 	{ MNSTR_KIND_CERBERUS,	/*  */
 		+0, +0, 89, 91, },
-	{ MNSTR_KIND_LESSER_DEMON,	/*  */
+	{ MNSTR_KIND_LESSER_DAEMON,	/*  */
 		+0, +0, 90, 92, },
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
+/* BOSS MNSTR_KIND_RELATIVISTIC_DAEMON, */	/*  */
 
 mnstr_lev_tab_t	mnstr_lev_tab_stage_10[] = {
 	{ MNSTR_KIND_A_RED_DRAGON,	/* --󥷥ȡɥ饴 */
@@ -420,7 +448,7 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_10[] = {
 		+0, +0, 97, 99, },
 	{ MNSTR_KIND_A_SILVER_DRAGON,	/* --󥷥ȡɥ饴 */
 		+0, +0, 98, 100, },
-	{ MNSTR_KIND_GREATER_DEMON,	/*  */
+	{ MNSTR_KIND_GREATER_DAEMON,	/*  */
 		+0, +0, 98, 100, },
 	{ MNSTR_KIND_A_GOLD_DRAGON,	/* --󥷥ȡɥ饴 */
 		+0, +0, 99, 100, },
@@ -429,6 +457,7 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_10[] = {
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
+/* BOSS MNSTR_KIND_ETERNAL_DRAGON, */	/* --󥷥ȡɥ饴 */
 
 mnstr_lev_tab_t	mnstr_lev_tab[MNSTR_KIND_MAX_N + 1];
 
@@ -639,7 +668,7 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_HYDRA,	/*  */
 		+1, +5, },
-	{ MNSTR_KIND_LESSER_DEMON,	/*  */
+	{ MNSTR_KIND_LESSER_DAEMON,	/*  */
 		+1, +5, },
 	{ MNSTR_KIND_M_WHITE_DRAGON,	/* --ޥʡɥ饴 */
 		+1, +2, },
@@ -671,7 +700,7 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_SPIRIT,	/* ǥå */
 		+1, +5, },
-	{ MNSTR_KIND_GREATER_DEMON,	/*  */
+	{ MNSTR_KIND_GREATER_DAEMON,	/*  */
 		+1, +5, },
 	{ MNSTR_KIND_A_RED_DRAGON,	/* --󥷥ȡɥ饴 */
 		+1, +5, },
