@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.78 2009/06/01 13:47:35 bowkenken Exp $
+* $Id: trap.c,v 1.79 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -79,6 +79,8 @@ static trap_t	trap_free;
 /* µܤγƥΥإå */
 static trap_t	dun_trap_asgn;
 
+check_memory_def( check_memory_trap_c_trap_buf )
+
 /* ǡơ֥κ */
 static long	trap_tab_max_n;
 
@@ -155,9 +157,11 @@ static trap_tab_t	trap_tab[] = {
 		TRUE,
 	},
 };
+check_memory_def( check_memory_trap_c_trap_tab )
 
 /* 櫤ˡȯưΥߡΥ饯 */
 chr_t	g_dmy_chr;
+check_memory_def( check_memory_trap_c_g_dmy_chr )
 
 /***************************************************************
 * 櫤ν
@@ -1484,3 +1488,16 @@ long	get_trap_tab_n( trap_kind_t kind )
 	return -1;
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_trap_c( void )
+{
+	check_memory( check_memory_trap_c_trap_buf,
+			"trap.c: trap_buf" );
+	check_memory( check_memory_trap_c_trap_tab,
+			"trap.c: trap_tab" );
+	check_memory( check_memory_trap_c_g_dmy_chr,
+			"trap.c: g_dmy_chr" );
+}
