@@ -25,13 +25,21 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.59 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: ver.h,v 1.62 2009/09/06 12:17:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
 #define	VER_H
 
-#define	STR_FILE_NAME_GAME	"lnl"
+#if	defined( D_WS ) || defined( D_GTK )
+# define	STR_FILE_NAME_GAME	"xlnl"
+#elif	defined( D_MFC )
+# define	STR_FILE_NAME_GAME	"xlnl-dows"
+#elif	defined( D_DOS )
+# define	STR_FILE_NAME_GAME	"lnl-dos"
+#else
+# define	STR_FILE_NAME_GAME	"lnl"
+#endif
 
 #define	STR_GAME_TITLE	"L&L - Labyrinths & Legends"
 #define	STR_VER_GAME	VERSION
@@ -50,16 +58,19 @@
 #define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"
 
 #define	STR_TITLE_3	" "
-#define	STR_HANDLE_3	"kokusi(yujyu), hiyo and URARA"
+#define	STR_HANDLE_3	"kokusi(yujyu), hiyo URARA"
 
-#define	STR_TITLE_4	"Photograph"
-#define	STR_HANDLE_4	"Yoshinori Kamimura"
+#define	STR_TITLE_4	" "
+#define	STR_HANDLE_4	"and naramura"
 
-#define	STR_TITLE_5	"Music Production"
-#define	STR_HANDLE_5	"Presence of Music"
+#define	STR_TITLE_5	"Photograph"
+#define	STR_HANDLE_5	"Yoshinori Kamimura"
+
+#define	STR_TITLE_6	"Music Production"
+#define	STR_HANDLE_6	"Presence of Music"
 
 #define	STR_TITLE_THANKS	"Special Thanks"
-#define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn and you"
+#define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn, lu and you"
 
 #define	STR_FMT_COPYRIGHT	\
 		"\n" \
@@ -79,6 +90,7 @@
 		"%20s  %-42s\n" \
 		"%20s  %-42s\n" \
 		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
 		"--------------------------------" \
 		"--------------------------------\n" \
 		""
@@ -93,6 +105,7 @@
 		STR_TITLE_3, STR_HANDLE_3, \
 		STR_TITLE_4, STR_HANDLE_4, \
 		STR_TITLE_5, STR_HANDLE_5, \
+		STR_TITLE_6, STR_HANDLE_6, \
 		STR_TITLE_THANKS, STR_HANDLE_THANKS
 
 #endif	/* VER_H */
